/** @packageDocumentation
 * @module Loading
 */
import "./LoadingPrompt.scss";
import * as React from "react";
import type { CommonProps } from "../utils/Props.js";
/** Properties for [[LoadingPrompt]] component
 * @public
 * @deprecated in 4.12.0. Props of deprecated component {@link LoadingPrompt}.
 */
export interface LoadingPromptProps extends CommonProps {
    /** Title */
    title: string;
    /** Message displayed below the title (optional) */
    message?: string;
    /** Determine if a percentage bar is displayed (isDeterminate=true), otherwise a loading spinner or indeterminate progress bar is shown. */
    isDeterminate: boolean;
    /** Show current status and percentage. Default is false (not shown) */
    showStatus: boolean;
    /** Show cancel button. Default is false (not shown) */
    showCancel: boolean;
    /** Current loading status text (optional). Only shown if showStatus=true and isDeterminate=true */
    status: string;
    /** Current percentage.  Only used if isDeterminate=true */
    percent: number;
    /** Show percentage at the end of the loading bar (optional). Only shown if isDeterminate=true and showStatus=false */
    showPercentage: boolean;
    /** Show indeterminate progress bar instead of loading spinner */
    showIndeterminateBar: boolean;
    /** Function called when Cancel button is clicked. */
    onCancel?: () => void;
}
/** A component to display during loading that optionally shows percentage, status text and a cancel button.
 * @public
 * @deprecated in 4.12.0. Use {@link https://itwinui.bentley.com/docs/progressindicator iTwinUI progress indicator} instead.
 */
export declare class LoadingPrompt extends React.PureComponent<LoadingPromptProps> {
    static defaultProps: Partial<LoadingPromptProps>;
    render(): React.JSX.Element;
}
//# sourceMappingURL=LoadingPrompt.d.ts.map