/** @packageDocumentation
 * @module Dialog
 */
import "./MessageBox.scss";
import * as React from "react";
import type { DialogButtonDef } from "@itwin/appui-abstract";
import { MessageSeverity } from "@itwin/appui-abstract";
import type { CommonProps } from "../utils/Props.js";
import type { IconSpec } from "../icons/IconComponent.js";
/** Properties for the [[MessageBox]] component
 * @public
 * @deprecated in 4.15.0. Props of deprecated {@link MessageBox} component.
 */
export interface MessageBoxProps extends CommonProps {
    /** Severity of MessageBox */
    severity: MessageSeverity;
    /** whether to show dialog or not */
    opened: boolean;
    /** List of [[DialogButtonDef]] objects specifying buttons and associated onClick events */
    buttonCluster: DialogButtonDef[];
    /** Title to show in title bar of dialog  */
    title?: string | React.ReactElement;
    /** onClick event for X button for dialog */
    onClose?: () => void;
    /** 'keyup' event for <Esc> key */
    onEscape?: () => void;
    /** minimum width that the dialog may be resized to. Default: 400 */
    minWidth?: number;
    /** minimum height that the dialog may be resized to. Default: 400 */
    minHeight?: number;
    /** initial width of dialog.
     * Displayed in px if value is a number, otherwise displayed in specified CSS unit.
     * Default: "50%"
     */
    width?: string | number;
    /** initial height of dialog.
     * Displayed in px if value is a number, otherwise displayed in specified CSS unit.
     * Default: ""
     */
    height?: string | number;
    /** Whether to show background overlay. Default: true */
    modal?: boolean;
    /** Custom CSS class name for the content */
    contentClassName?: string;
    /** Custom CSS Style for the content */
    contentStyle?: React.CSSProperties;
    /** Message content */
    children?: React.ReactNode;
}
/** Message Box React component.
 * @public
 * @deprecated in 4.15.0. Use {@link https://itwinui.bentley.com/docs/dialog iTwinUI Dialog} instead.
 */
export declare class MessageBox extends React.PureComponent<MessageBoxProps> {
    static defaultProps: Partial<MessageBoxProps>;
    render(): React.ReactElement;
}
/** Properties for the [[MessageContainer]] component
 * @public
 * @deprecated in 4.15.0. Props of deprecated {@link MessageContainer} component.
 */
export interface MessageContainerProps extends CommonProps {
    severity: MessageSeverity;
    /** Message Content */
    children?: React.ReactNode;
}
/** Message Container React component.
 * @public
 * @deprecated in 4.15.0. Use {@link https://itwinui.bentley.com/docs/dialog iTwinUI Dialog} instead.
 */
export declare class MessageContainer extends React.PureComponent<MessageContainerProps> {
    /** Returns the class name corresponding to the MessageSeverity.
     * @param severity MessageSeverity
     */
    static getIconClassName(severity: MessageSeverity): string;
    /** Returns the class name associated with the WebFont icon corresponding to the MessageSeverity.
     * @param severity MessageSeverity
     * @param hollow Should the icon be hollow
     * @deprecated in 4.0.0. Hollow parameter ignored, WebFont is not returned, only the color.
     */
    static getIconClassName(severity: MessageSeverity, hollow?: boolean): string;
    /** Returns the React icon corresponding to the MessageSeverity.
     * @param severity MessageSeverity
     * @param hollow set to true to return the hollow form of the icon.
     * @returns IconSpec
     */
    static getIcon(severity: MessageSeverity, hollow?: boolean): IconSpec;
    render(): React.ReactElement;
}
//# sourceMappingURL=MessageBox.d.ts.map