/** @packageDocumentation
 * @module RadialMenu
 */
import { Point } from "../utils/Point.js";
/** 2D Line consisting of a start point, and an end point
 * @internal
 */
export declare class Line {
    p1: Point;
    p2: Point;
    constructor(p1?: Point, p2?: Point);
    /** checks for equality with the components of this, and line parameter */
    equals: (line: Line) => boolean;
}
/** 2D Circle.
 * @internal
 */
export declare class Circle {
    center: Point;
    radius: number;
    constructor(center?: Point, radius?: number);
}
/** 2D Annulus (2D doughnut shape/flattened torus) defined by an inner and outer circle with a shared center point.
 * @internal
 */
export declare class Annulus {
    center: Point;
    inner: Circle;
    outer: Circle;
    constructor(center?: Point, innerRadius?: number, outerRadius?: number);
}
/** 2D Sector of an Annulus, defined by both a parent annulus, a startAngle, and an endAngle.
 * @internal
 */
export declare class AnnularSector {
    parent: Annulus;
    startAngle: number;
    endAngle: number;
    path: string;
    innerStart: Point;
    outerStart: Point;
    start: Line;
    innerEnd: Point;
    outerEnd: Point;
    end: Line;
    /**
     * initialize AnnularSector on parent annulus, and generate SVG Path to store in this.path
     * @param parent parent annulus to initialize sector on.
     * @param startAngle angle to begin the annular sector on.
     * @param endAngle angle to end the annular sector on.
     */
    constructor(parent: Annulus, startAngle: number, endAngle: number);
}
//# sourceMappingURL=Annulus.d.ts.map