/*---------------------------------------------------------------------------------------------
 * Copyright (c) Bentley Systems, Incorporated. All rights reserved.
 * See LICENSE.md in the project root for license terms and full copyright notice.
 *--------------------------------------------------------------------------------------------*/
/** @packageDocumentation
 * @module Text
 */
import * as React from "react";
import classnames from "classnames";
import "./FilteredText.scss";
/** Component used to highlight filter matches within a text string.
 * @alpha
 * @deprecated in 4.15.0. Used internally.
 */
// eslint-disable-next-line @typescript-eslint/no-deprecated
export function FilteredText(props) {
    const { value, className, matches, matchClassName, matchStyle, ...otherProps } = props;
    if (matches && matches.length > 0) {
        const spans = [];
        let startPos = 0;
        for (const span of matches) {
            if (span.start !== startPos)
                spans.push(React.createElement("span", { key: startPos, className: "uicore-partial-filtered-text" }, value.substring(startPos, span.start)));
            spans.push(React.createElement("span", { key: span.start, style: matchStyle, className: classnames("uicore-filtered-text-match", matchClassName) }, value.substring(span.start, span.end)));
            startPos = span.end;
        }
        const endPos = value.length;
        if (startPos < endPos) {
            spans.push(React.createElement("span", { key: startPos, className: "uicore-partial-filtered-text" }, value.substring(startPos, endPos)));
        }
        return (React.createElement("div", { ...otherProps, className: classnames("uicore-filtered-text", className), title: value }, spans));
    }
    return (React.createElement("span", { ...otherProps, className: classnames("uicore-filtered-text", className), title: value }, value));
}
//# sourceMappingURL=FilteredText.js.map